==> haskell-either-5.0.2-163-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 either
version:              5.0.2
visibility:           public
id:                   either-5.0.2-KJSurByLz86Ck4Hkzt9tEV
key:                  either-5.0.2-KJSurByLz86Ck4Hkzt9tEV
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2017 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/either/
synopsis:             Combinators for working with sums
description:          Combinators for working with sums.
category:             Control, Monads
abi:                  dda45c901a9420a6bdd3f14a4ccba66e
exposed:              True
exposed-modules:      Data.Either.Combinators Data.Either.Validation
import-dirs:          /usr/lib/ghc-9.4.8/site-local/either-5.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/either-5.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/either-5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-either
hs-libraries:         HSeither-5.0.2-KJSurByLz86Ck4Hkzt9tEV
depends:
    base-4.17.2.1 bifunctors-5.6-H5gLaZGTtKN1h3rKcuS2CV mtl-2.2.2
    profunctors-5.6.2-HcmQMl1CmCsL3Ph63hJBuk
    semigroupoids-6.0.1-4tZ3GUdbU6C6aZsHetCI4X

haddock-interfaces:   /usr/share/doc/haskell-either/html/either.haddock
haddock-html:         /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-either-5.0.2-164-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 either
version:              5.0.2
visibility:           public
id:                   either-5.0.2-7xPKf9yorGQ3wsnuWrmq77
key:                  either-5.0.2-7xPKf9yorGQ3wsnuWrmq77
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2017 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/either/
synopsis:             Combinators for working with sums
description:          Combinators for working with sums.
category:             Control, Monads
abi:                  81805f55f1e3877d855b598e17212ce3
exposed:              True
exposed-modules:      Data.Either.Combinators Data.Either.Validation
import-dirs:          /usr/lib/ghc-9.4.8/site-local/either-5.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/either-5.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/either-5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-either
hs-libraries:         HSeither-5.0.2-7xPKf9yorGQ3wsnuWrmq77
depends:
    base-4.17.2.1 bifunctors-5.6-KLcmucI6NacAyWgzCaf5ds mtl-2.2.2
    profunctors-5.6.2-9gaZVxUbwLy9jyhD2zEf8q
    semigroupoids-6.0.1-6WCIMcArKfqCbwJxNv0JB0

haddock-interfaces:   /usr/share/doc/haskell-either/html/either.haddock
haddock-html:         /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
